==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ClassAsSubtypeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSubtype;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSubtypeSet;
import io.ciera.tool.sql.ooaofooa.association.ReferringClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.SubtypeSupertypeAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferringClassInAssocSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.SubtypeSupertypeAssociationSetImpl;

import java.util.Arrays;
import java.util.List;


public class ClassAsSubtypeSetImpl extends InstanceSet<ClassAsSubtypeSet,ClassAsSubtype> implements ClassAsSubtypeSet {

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ClassAsSubtype classassubtype : this ) classassubtype.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ClassAsSubtype classassubtype : this ) classassubtype.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassAsSubtype classassubtype : this ) classassubtype.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public ReferringClassInAssocSet R205_is_a_ReferringClassInAssoc() throws XtumlException {
        ReferringClassInAssocSet referringclassinassocset = new ReferringClassInAssocSetImpl();
        for ( ClassAsSubtype classassubtype : this ) referringclassinassocset.add( classassubtype.R205_is_a_ReferringClassInAssoc() );
        return referringclassinassocset;
    }
    @Override
    public SubtypeSupertypeAssociationSet R213_is_related_to_supertype_via_SubtypeSupertypeAssociation() throws XtumlException {
        SubtypeSupertypeAssociationSet subtypesupertypeassociationset = new SubtypeSupertypeAssociationSetImpl();
        for ( ClassAsSubtype classassubtype : this ) subtypesupertypeassociationset.add( classassubtype.R213_is_related_to_supertype_via_SubtypeSupertypeAssociation() );
        return subtypesupertypeassociationset;
    }


    @Override
    public ClassAsSubtype nullElement() {
        return ClassAsSubtypeImpl.EMPTY_CLASSASSUBTYPE;
    }

    @Override
    public ClassAsSubtypeSet emptySet() {
      return new ClassAsSubtypeSetImpl();
    }

    @Override
    public ClassAsSubtypeSet value() {
        return this;
    }

    @Override
    public List<ClassAsSubtype> elements() {
        return Arrays.asList(toArray(new ClassAsSubtype[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ClassAsSubtypeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSubtype;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSubtypeSet;
import io.ciera.tool.sql.ooaofooa.association.ReferringClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.SubtypeSupertypeAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferringClassInAssocSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.SubtypeSupertypeAssociationSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ClassAsSubtypeSetImpl extends InstanceSet<ClassAsSubtypeSet,ClassAsSubtype> implements ClassAsSubtypeSet {

    public ClassAsSubtypeSetImpl() {
    }

    public ClassAsSubtypeSetImpl(Comparator<? super ClassAsSubtype> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ClassAsSubtype classassubtype : this ) classassubtype.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ClassAsSubtype classassubtype : this ) classassubtype.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassAsSubtype classassubtype : this ) classassubtype.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public ReferringClassInAssocSet R205_is_a_ReferringClassInAssoc() throws XtumlException {
        ReferringClassInAssocSet referringclassinassocset = new ReferringClassInAssocSetImpl();
        for ( ClassAsSubtype classassubtype : this ) referringclassinassocset.add( classassubtype.R205_is_a_ReferringClassInAssoc() );
        return referringclassinassocset;
    }
    @Override
    public SubtypeSupertypeAssociationSet R213_is_related_to_supertype_via_SubtypeSupertypeAssociation() throws XtumlException {
        SubtypeSupertypeAssociationSet subtypesupertypeassociationset = new SubtypeSupertypeAssociationSetImpl();
        for ( ClassAsSubtype classassubtype : this ) subtypesupertypeassociationset.add( classassubtype.R213_is_related_to_supertype_via_SubtypeSupertypeAssociation() );
        return subtypesupertypeassociationset;
    }


    @Override
    public ClassAsSubtype nullElement() {
        return ClassAsSubtypeImpl.EMPTY_CLASSASSUBTYPE;
    }

    @Override
    public ClassAsSubtypeSet emptySet() {
      return new ClassAsSubtypeSetImpl();
    }

    @Override
    public ClassAsSubtypeSet emptySet(Comparator<? super ClassAsSubtype> comp) {
      return new ClassAsSubtypeSetImpl(comp);
    }

    @Override
    public ClassAsSubtypeSet value() {
        return this;
    }

    @Override
    public List<ClassAsSubtype> elements() {
        return Arrays.asList(toArray(new ClassAsSubtype[0]));
    }

}
